/*
 *  Created by Pasi Lallinaho <pasi@shimmerproject.org>
 *  The license of this file is CC-BY-SA 2.0.
 *	
 */

@import url('reset.css');

body {
	background-color: #eee;

	font-family: "Droid Sans", sans-serif;
	font-size: small;
	line-height: 1.3em;
}

#header {
	max-width: 950px;
	margin: 3em auto 1em auto;
	padding: 0 3em;
	line-height: 1.5em;
}

#content {
	max-width: 950px;
	min-width: 580px;
	margin: 1em auto;

	padding: 3em;
	line-height: 1.5em;

	background-color: #fff;

	-webkit-border-radius: 10px;
	-moz-border-radius: 10px;
	border-radius: 10px;	
}

/* */

h1 {
	margin: 0 0 1em 0;
	font-size: 200%;
	line-height: 1.2em;
}

h2 {
	margin: 1em 0;

	font-size: 180%;
	font-weight: normal;
	line-height: 1.2em;

	color: #555;
}

	h2.intro {
		color: #2c5aa4;
		font-size: 200%;
	}

p {
	margin-bottom: 1em;
	font-size: 105%;
	line-height: 1.4em;
}

a {
	color: #2774e7;
	border-bottom: 1px solid #aaa;
	text-decoration: none;
}

ol {
	margin-bottom: 1.5em;
	font-size: 130%;
	line-height: 1.5em;
}

	ol li {
		list-style-type: decimal;
		margin-left: 1.3em;
	}

ul {
	margin-bottom: 1em;
}

ul li {
	list-style-type: square;
	list-style-position: inside;
}

ul.inline li {
	list-style-type: none;
	display: inline;
	margin-right: 0.5em;
}